@@ -1,15 +1,17 @@
-import json
 import os
+import json
 from datetime import date, datetime, time, timedelta
 from urllib.parse import urlparse
 
-from dotenv import load_dotenv
+from .mini_logger import MiniLogger
 
-from .mini_logger import MiniLogger as logger
-from .validate_environment import validate_brand_name
-from .validate_environment import validate_environment_name
+from .constants import (BRAND_NAME, ENVIRONMENT_NAME)  # noqa: E402
 
-load_dotenv()
+from .validate_environment import (validate_brand_name,  # noqa: E402
+                                   validate_environment_name)
+
+
+RANGE_LENGTH = 2
 
 
 def timedelta_to_time_format(time_delta: timedelta) -> str:
@@ -32,7 +34,7 @@ def timedelta_to_time_format(time_delta: timedelta) -> str:
         '02:30:45'
     """
     TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME = "timedelta_to_time_format"
-    logger.start(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME, object={'time_delta': time_delta})
+    MiniLogger.start(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME, object={'time_delta': time_delta})
 
     # Calculate the total seconds and convert to HH:MM:SS format
     total_seconds = int(time_delta.total_seconds())
@@ -43,8 +45,8 @@ def timedelta_to_time_format(time_delta: timedelta) -> str:
     # Format as "HH:MM:SS"
     formatted_time = f"{hours:02d}:{minutes:02d}:{seconds:02d}"
 
-    logger.end(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME,
-               object={'formatted_time': formatted_time})
+    MiniLogger.end(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME,
+                   object={'formatted_time': formatted_time})
     return formatted_time
 
 
@@ -53,25 +55,25 @@ def is_valid_time_range(time_range: tuple) -> bool:
     Validate that the time range is in the format 'HH:MM:SS'.
     """
     IS_VALID_TIME_RANGE_METHOD_NAME = "is_valid_time_range"
-    logger.start(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+    MiniLogger.start(IS_VALID_TIME_RANGE_METHOD_NAME, object={
         "time_range": time_range.__str__()})
-    if len(time_range) != 2:
-        logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+    if len(time_range) != RANGE_LENGTH:
+        MiniLogger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
             "is_valid_time_range_result": False, "reason": "len(time_range) != 2"})
         return False
 
     for time_obj in time_range:
         if not isinstance(time_obj, time):
-            logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+            MiniLogger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
                 "is_valid_time_range_result": False, "reason": "time_range contains non-time objects"})
             return False
         time_str = time_obj.strftime('%H:%M:%S')
         if time_obj.strftime('%H:%M:%S') != time_str:
-            logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+            MiniLogger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
                 "is_valid_time_range_result": False, "reason": "time_range contains invalid time format"})
             return False
 
-    logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
+    MiniLogger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
         "is_valid_time_range_result": True})
     return True
 
@@ -88,19 +90,19 @@ def is_valid_date_range(date_range: tuple) -> bool:
     Validate that the date range is in the format 'YYYY-MM-DD'.
     """
     IS_VALID_DATE_RANGE_METHOD_NAME = "is_valid_date_range"
-    logger.start(IS_VALID_DATE_RANGE_METHOD_NAME, object={
+    MiniLogger.start(IS_VALID_DATE_RANGE_METHOD_NAME, object={
         "date_range": date_range.__str__()})
-    if len(date_range) != 2:
-        logger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
+    if len(date_range) != RANGE_LENGTH:
+        MiniLogger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
             "is_valid_date_range_result": False, "reason": "len(date_range) != 2"})
         return False
 
     for date_obj in date_range:
         if not isinstance(date_obj, date):
-            logger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
+            MiniLogger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
                 "is_valid_date_range_result": False, "reason": "date_range contains non-date objects"})
             return False
-    logger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
+    MiniLogger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
         "is_valid_date_range_result": True})
     return True
 
@@ -110,19 +112,19 @@ def is_valid_datetime_range(datetime_range: tuple) -> bool:
     Validate that the datetime range is in the format 'YYYY-MM-DD HH:MM:SS'.
     """
     IS_VALID_DATETIME_RANGE_METHOD_NAME = "is_valid_datetime_range"
-    logger.start(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
+    MiniLogger.start(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
         "datetime_range": datetime_range.__str__()})
-    if len(datetime_range) != 2:
-        logger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
+    if len(datetime_range) != RANGE_LENGTH:
+        MiniLogger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
             "is_valid_datetime_range_result": False, "reason": "len(datetime_range) != 2"})
         return False
 
     for datetime_obj in datetime_range:
         if not isinstance(datetime_obj, datetime):
-            logger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
+            MiniLogger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
                 "is_valid_datetime_range_result": False, "reason": "datetime_range contains non-datetime objects"})
             return False
-    logger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
+    MiniLogger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
         "is_valid_datetime_range_result": True})
     return True
 
@@ -151,27 +153,26 @@ def is_list_of_dicts(obj):
         False
     """
     IS_LIST_OF_DICTS_FUNCTION_NAME = "is_list_of_dicts"
-    logger.start(IS_LIST_OF_DICTS_FUNCTION_NAME, object={"obj": obj})
+    MiniLogger.start(IS_LIST_OF_DICTS_FUNCTION_NAME, object={"obj": obj})
     try:
         if not isinstance(obj, list):
             is_list_of_dicts_result = False
-            logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
+            MiniLogger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
                 "is_list_of_dicts_result": is_list_of_dicts_result})
             return is_list_of_dicts_result
         for item in obj:
             if not isinstance(item, dict):
                 is_list_of_dicts_result = False
-                logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
+                MiniLogger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
                     "is_list_of_dicts_result": is_list_of_dicts_result})
                 return is_list_of_dicts_result
         is_list_of_dicts_result = True
-        logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
+        MiniLogger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
             "is_list_of_dicts_result": is_list_of_dicts_result})
         return is_list_of_dicts_result
-    except Exception as exception:
-        logger.exception(IS_LIST_OF_DICTS_FUNCTION_NAME, exception)
-        logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME)
-        raise
+    except Exception as e:
+        MiniLogger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, exception=e)
+        raise e
 
 
 def is_time_in_time_range(check_time: time, time_range: tuple) -> bool:
@@ -186,14 +187,14 @@ def is_time_in_time_range(check_time: time, time_range: tuple) -> bool:
         bool: True if the check_time is within the time range, False otherwise.
     """
     IS_TIME_IN_TIME_RANGE_METHOD_NAME = "is_time_in_time_range"
-    logger.start(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
+    MiniLogger.start(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
         "check_time": check_time.__str__(), "time_range": time_range.__str__()})
     if not is_valid_time_range(time_range) or not isinstance(check_time, time):
-        logger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
+        MiniLogger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
             "is_time_in_time_range_result": False})
         return False
     start_time, end_time = time_range
-    logger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
+    MiniLogger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
         "is_time_in_time_range_result": start_time <= check_time <= end_time})
     return start_time <= check_time <= end_time
 
@@ -210,15 +211,15 @@ def is_date_in_date_range(check_date: date, date_range: tuple) -> bool:
         bool: True if the check_date is within the date range, False otherwise.
     """
     IS_DATE_IN_DATE_RANGE_METHOD_NAME = "is_date_in_date_range"
-    logger.start(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
+    MiniLogger.start(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
         "check_date": check_date.__str__(), "date_range": date_range.__str__()})
     if not is_valid_date_range(date_range) or not isinstance(check_date, date):
-        logger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
+        MiniLogger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
             "is_date_in_date_range_result": False})
         return False
 
     start_date, end_date = date_range
-    logger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
+    MiniLogger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
         "is_date_in_date_range_result": start_date <= check_date <= end_date})
     return start_date <= check_date <= end_date
 
@@ -235,15 +236,15 @@ def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: tupl
         bool: True if the check_datetime is within the datetime range, False otherwise.
     """
     IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME = "is_datetime_in_datetime_range"
-    logger.start(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME)
+    MiniLogger.start(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME)
     if not is_valid_datetime_range(datetime_range) or not isinstance(check_datetime, datetime):
-        logger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
+        MiniLogger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
             "is_valid_datetime_range": False})
         return False
 
     start_datetime, end_datetime = datetime_range
     is_datetime_in_datetime_range_result = start_datetime <= check_datetime <= end_datetime
-    logger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
+    MiniLogger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
         "is_datetime_in_datetime_range_result": is_datetime_in_datetime_range_result})
     return is_datetime_in_datetime_range_result
 
@@ -277,16 +278,19 @@ def create_http_body(body):
 
 def get_brand_name():
     validate_brand_name()
-    return our_get_env("BRAND_NAME")
+    return BRAND_NAME
 
 
 def get_environment_name():
     validate_environment_name()
-    return our_get_env("ENVIRONMENT_NAME")
+    return ENVIRONMENT_NAME
 
 
-def our_get_env(key: str, default: str = None) -> str:
-    return os.getenv(key, default)
+def our_get_env(key: str, default: str = None, raise_if_not_found: bool = True) -> str:
+    result = os.getenv(key, default)
+    if raise_if_not_found and result is None:
+        raise Exception(f"Environment variable {key} not found")
+    return result
 
 
 def get_sql_hostname() -> str:
@@ -298,4 +302,4 @@ def get_sql_username() -> str:
 
 
 def get_sql_password() -> str:
-    return our_get_env("RDS_PASSWORD")
+    return our_get_env("RDS_PASSWORD")
\ No newline at end of file
